/********************************************************
 *  ██████╗  ██████╗████████╗██╗
 * ██╔════╝ ██╔════╝╚══██╔══╝██║
 * ██║  ███╗██║        ██║   ██║
 * ██║   ██║██║        ██║   ██║
 * ╚██████╔╝╚██████╗   ██║   ███████╗
 *  ╚═════╝  ╚═════╝   ╚═╝   ╚══════╝
 * Geophysical Computational Tools & Library (GCTL)
 *
 * Copyright (c) 2023  Yi Zhang (yizhang-geo@zju.edu.cn)
 *
 * GCTL is distributed under a dual licensing scheme. You can redistribute 
 * it and/or modify it under the terms of the GNU Lesser General Public 
 * License as published by the Free Software Foundation, either version 2 
 * of the License, or (at your option) any later version. You should have 
 * received a copy of the GNU Lesser General Public License along with this 
 * program. If not, see <http://www.gnu.org/licenses/>.
 * 
 * If the terms and conditions of the LGPL v.2. would prevent you from using 
 * the GCTL, please consider the option to obtain a commercial license for a 
 * fee. These licenses are offered by the GCTL's original author. As a rule, 
 * licenses are provided "as-is", unlimited in time for a one time fee. Please 
 * send corresponding requests to: yizhang-geo@zju.edu.cn. Please do not forget 
 * to include some description of your company and the realm of its activities. 
 * Also add information on how to contact you by electronic and paper mail.
 ******************************************************/

#include "../lib/core.h"
#include "../lib/io.h"

using namespace gctl;

int main(int argc, char const *argv[]) try
{
    text_content tc("tmp/topo");

    array<double> x(tc.contents_.size());
    array<double> y(tc.contents_.size());
    array<double> z(tc.contents_.size());

    for (size_t i = 0; i < tc.contents_.size(); i++)
    {
        parse_string_to_value(tc.contents_[i], ' ', true, x[i], y[i], z[i]);
    }

    std::clog << x.back() << "," << y.back() << "," << z.back() << "\n";
    display_vector(tc.annotates_, std::clog, '\n');
    display_vector(tc.tags_, std::clog, '\n');
    display_vector(tc.heads_, std::clog, '\n');
    return 0;
}
catch(std::exception &e)
{
    GCTL_ShowWhatError(e.what(), GCTL_ERROR_ERROR, 0, 0, 0);
}